==> estateplat-common-1.2.1-20170613.075027-31-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyResult.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Table;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * User: zq
 * Date: 15-12-30
 * Time: 下午11:15
 * To change this template use File | Settings | File Templates.
 */
public class InfApplyResult {
	private String no;//流水号
	private String org_id;//部门编码
	private String internal_no;//部门内部办件编号
	private String item_id;//权力编码
	private String status;//办结状态
	private String note;//办结意见
	private String attachment;//办理附件
	private Date finish_date;//办结时间
	private Date create_date;//录入自建系统时间
	private Date update_date;//写入前置机时间
	private Date sync_date;//信息同步读取时间
	private String sync_sign;//信息同步标志
	private String sync_error_desc;//信息同步错误原因

	public String getNo() {
		return no;
	}

	public void setNo(String no) {
		this.no = no;
	}

	public String getOrg_id() {
		return org_id;
	}

	public void setOrg_id(String org_id) {
		this.org_id = org_id;
	}

	public String getInternal_no() {
		return internal_no;
	}

	public void setInternal_no(String internal_no) {
		this.internal_no = internal_no;
	}

	public String getItem_id() {
		return item_id;
	}

	public void setItem_id(String item_id) {
		this.item_id = item_id;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getNote() {
		return note;
	}

	public void setNote(String note) {
		this.note = note;
	}

	public String getAttachment() {
		return attachment;
	}

	public void setAttachment(String attachment) {
		this.attachment = attachment;
	}

	public Date getFinish_date() {
		return finish_date;
	}

	public void setFinish_date(Date finish_date) {
		this.finish_date = finish_date;
	}

	public Date getCreate_date() {
		return create_date;
	}

	public void setCreate_date(Date create_date) {
		this.create_date = create_date;
	}

	public Date getUpdate_date() {
		return update_date;
	}

	public void setUpdate_date(Date update_date) {
		this.update_date = update_date;
	}

	public Date getSync_date() {
		return sync_date;
	}

	public void setSync_date(Date sync_date) {
		this.sync_date = sync_date;
	}

	public String getSync_sign() {
		return sync_sign;
	}

	public void setSync_sign(String sync_sign) {
		this.sync_sign = sync_sign;
	}

	public String getSync_error_desc() {
		return sync_error_desc;
	}

	public void setSync_error_desc(String sync_error_desc) {
		this.sync_error_desc = sync_error_desc;
	}
}

==> estateplat-common-1.2.3-20180103.012305-3-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyResult.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * User: zq
 * Date: 15-12-30
 * Time: 下午11:15
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "inf_apply_result")
public class InfApplyResult {
	@Id
	private String no;//流水号
	private String org_id;//部门编码
	private String internal_no;//部门内部办件编号
	private String item_id;//权力编码
	private String status;//办结状态
	private String note;//办结意见
	private String attachment;//办理附件
	private Date finish_date;//办结时间
	private Date create_date;//录入自建系统时间
	private Date update_date;//写入前置机时间
	private Date sync_date;//信息同步读取时间
	private String sync_sign;//信息同步标志
	private String sync_error_desc;//信息同步错误原因

	private String result_no;//许可/不予许可文号
	private String result_file_name;//决定附件名称
	private byte[] result_file;//决定附件
	private Date result_date;//决定时间
	private String data_sources;//数据来源
	private String user_name;//办理人员姓名

	public String getNo() {
		return no;
	}

	public void setNo(String no) {
		this.no = no;
	}

	public String getOrg_id() {
		return org_id;
	}

	public void setOrg_id(String org_id) {
		this.org_id = org_id;
	}

	public String getInternal_no() {
		return internal_no;
	}

	public void setInternal_no(String internal_no) {
		this.internal_no = internal_no;
	}

	public String getItem_id() {
		return item_id;
	}

	public void setItem_id(String item_id) {
		this.item_id = item_id;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getNote() {
		return note;
	}

	public void setNote(String note) {
		this.note = note;
	}

	public String getAttachment() {
		return attachment;
	}

	public void setAttachment(String attachment) {
		this.attachment = attachment;
	}

	public Date getFinish_date() {
		return finish_date;
	}

	public void setFinish_date(Date finish_date) {
		this.finish_date = finish_date;
	}

	public Date getCreate_date() {
		return create_date;
	}

	public void setCreate_date(Date create_date) {
		this.create_date = create_date;
	}

	public Date getUpdate_date() {
		return update_date;
	}

	public void setUpdate_date(Date update_date) {
		this.update_date = update_date;
	}

	public Date getSync_date() {
		return sync_date;
	}

	public void setSync_date(Date sync_date) {
		this.sync_date = sync_date;
	}

	public String getSync_sign() {
		return sync_sign;
	}

	public void setSync_sign(String sync_sign) {
		this.sync_sign = sync_sign;
	}

	public String getSync_error_desc() {
		return sync_error_desc;
	}

	public void setSync_error_desc(String sync_error_desc) {
		this.sync_error_desc = sync_error_desc;
	}

	public String getResult_no() {
		return result_no;
	}

	public void setResult_no(String result_no) {
		this.result_no = result_no;
	}

	public String getResult_file_name() {
		return result_file_name;
	}

	public void setResult_file_name(String result_file_name) {
		this.result_file_name = result_file_name;
	}

	public byte[] getResult_file() {
		return result_file;
	}

	public void setResult_file(byte[] result_file) {
		this.result_file = result_file;
	}

	public Date getResult_date() {
		return result_date;
	}

	public void setResult_date(Date result_date) {
		this.result_date = result_date;
	}

	public String getData_sources() {
		return data_sources;
	}

	public void setData_sources(String data_sources) {
		this.data_sources = data_sources;
	}

	public String getUser_name() {
		return user_name;
	}

	public void setUser_name(String user_name) {
		this.user_name = user_name;
	}
}
